/**
Copyright 2015 Bsharp Inc. http://bsharp.jp/
Licensed under GPL.
Download, Support: http://mamewaza.com/tools/
*/

//ブログの表示
(function($) {

$.mamewaza_blog = function(conf) {
	//デフォルト値
	var dft = {
		//設置対象要素のjQuery selector
		selector: "#blog",
		//Feedアドレス
		feed: "",
		//表示件数（1～10）
		rpp: "10",
		//表示部分の高さ（autoまたは数字、単位はpx、「px」は不要）
		height: "auto",
		//本文表示有無（boolean）
		exp: true,
		//URL表示有無（boolean）
		url: true,
		//日付表示の有無とフォーマット（下記参照）
		//0: なし
		//1: 2015年12月31日
		//2: 2015年12月31日 01:23:45
		//3: 201512/31
		//4: 201512/31 01:23:45
		date: 0,
		//cssのパス
		cssPath: "./mamewaza_blog/mamewaza_blog.css"
	};

	conf = $.extend({}, dft, conf);
	conf.date = parseInt(conf.date, 10);

	//値の確認
	if(!conf.selector || !$(conf.selector)[0] || !conf.feed || !conf.feed.toString().match(/^https?:\/\//i) ) {
		return "";
	}

	//日時表示の成形
	var zerofill = function(time) {
		return time < 10 ? "0" + time : time;
	};
	var format = function(str) {
		if(!conf.date) {
			return "";
		}

		if(str.match(/^(\d{4})(?:-|\/)(\d{2})(?:-|\/)(\d{2})\D+(\d{2}):(\d{2}):(\d{2})(?:\+\d{2}:\d{2})?$/) ) {
			var t = new Date(RegExp.$1, RegExp.$2 - 1, RegExp.$3, RegExp.$4, RegExp.$5, RegExp.$6);
		} else {
			var t = new Date(str);
		}

		//IE用（「Fri Oct 21 10:17:42 +0000 2011」を「Fri Oct 21 2011 10:17:42 +0000」にする）
		if(isNaN(t) ) {
			var t_arr = str.split(" ");
			str = [t_arr[0], t_arr[1], t_arr[5], t_arr[2], t_arr[3], t_arr[4]].join(" ");
			t = new Date(str);
		}

		var is_slash = conf.date == 3 || conf.date == 4;
		var with_time = conf.date == 2 || conf.date == 4;
		return t.getFullYear() + (is_slash ? "/" : "年") + (t.getMonth() + 1) + (is_slash ? "/" : "月") + t.getDate() + (is_slash ? "" : "日")
			+ (with_time ? " " + zerofill(t.getHours() ) + ":" + zerofill(t.getMinutes() ) + ":" + zerofill(t.getSeconds() ) : "");
	};

	//表示
	var set = function(res) {
		if(!res || res.error || !res.feed || !res.feed.entries) {
			return "";
		}

		//タイトルの設置
		var html = "<div><h5 class=\"mamewaza_blog\"><a href=\"" + res.feed.link + "\" target=\"_blank\">" + res.feed.title + "</a></h5>";
		//entriesの設置
		html += "<ul class=\"mamewaza_blog\"" + (conf.height && conf.height.toString().match(/^\d+$/) ? " style=\"height:" + conf.height + "px\"" : "") + ">";
		for(var i = 0; i < res.feed.entries.length; i++) {
			//広告の排除
			if(res.feed.entries[i].title.match(/^PR:/) ) {
				continue;
			}

			html += "<li><a href=\"" + res.feed.entries[i].link + "\" target=\"_blank\" class=\"mamewaza_blog_title\">" + res.feed.entries[i].title + "</a>"
				+ (conf.exp ? "<span class=\"mamewaza_blog_exp\">" + res.feed.entries[i].contentSnippet.substr(0, 30) + "...</span>" : "")
				+ (conf.date ? "<span class=\"mamewaza_blog_date\">" + format(res.feed.entries[i].publishedDate) + "</span>" : "")
				+ (conf.url ? "<a href=\"" + res.feed.entries[i].link + "\" target=\"_blank\" class=\"mamewaza_blog_url\">" + res.feed.entries[i].link + "</a>" : "")
				+ "</li>";
		}
		html += "</ul>"
			+ "<div class=\"mamewaza_blog_exp\" style=\"display:block !important;visibility:visible !important;position:static !important;\">"
			+ "<span class=\"memewaza_asscembled\">assembled by <a href=\"http://mamewaza.com/\" target=\"_blank\">まめわざ</a></span>"
			+ "</div>"
			+ "</div>";

		$(conf.selector).html(html);
	};

	//初期設定（googleの読込、cssの読込、google feed API実行）
	var init = function() {
		//google.feedsが無い場合
		if(typeof(google) == "undefined" || typeof(google.load) == "undefined") {
			$.ajax( {
				"timeout": 5000,
				"url": "https://www.google.com/jsapi",
				"dataType": "script",
				"success": init,
				"error": function(res, status) {
				}
			} );
			return "";

		} else if(typeof(google.feeds) == "undefined") {
			google.load("feeds", "1", {
				"callback": init
			} );
			return "";
		}

		//外部cssの読込
		if(document.createStyleSheet) {
			document.createStyleSheet(conf.cssPath);
		} else {
			$("head").append("<link href=\"" + conf.cssPath + "\" rel=\"stylesheet\" type=\"text/css\" />");
		}

		//読み込み
		var hash = ("0" + (new Date().getMonth() + 1).toString() ).slice(-2) + ("0" + (new Date().getDate() ).toString() ).slice(-2);
		var url = conf.feed + (conf.feed.indexOf("?") != -1 ? "&" : "?") + hash;
		var req = new google.feeds.Feed(url);
		req.setNumEntries(conf.rpp);
		req.load(set);
	};

	init();
};

})(jQuery);
